==> chaosmesh-model-5.3.0-sources.jar: annotations/io/fabric8/chaosmesh/v1alpha1/JVMExceptionSpecFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.StringBuffer;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;

public interface JVMExceptionSpecFluent<A extends JVMExceptionSpecFluent<A>> extends Fluent<A> {


    public Boolean getAfter();
    public A withAfter(Boolean after);
    public Boolean hasAfter();
    public A withNewAfter(String arg1);
    public A withNewAfter(boolean arg1);
    public String getClassname();
    public A withClassname(String classname);
    public Boolean hasClassname();
    public A withNewClassname(StringBuilder arg1);
    public A withNewClassname(int[] arg1,int arg2,int arg3);
    public A withNewClassname(char[] arg1);
    public A withNewClassname(StringBuffer arg1);
    public A withNewClassname(byte[] arg1,int arg2);
    public A withNewClassname(byte[] arg1);
    public A withNewClassname(char[] arg1,int arg2,int arg3);
    public A withNewClassname(byte[] arg1,int arg2,int arg3);
    public A withNewClassname(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewClassname(String arg1);
    public String getException();
    public A withException(String exception);
    public Boolean hasException();
    public A withNewException(StringBuilder arg1);
    public A withNewException(int[] arg1,int arg2,int arg3);
    public A withNewException(char[] arg1);
    public A withNewException(StringBuffer arg1);
    public A withNewException(byte[] arg1,int arg2);
    public A withNewException(byte[] arg1);
    public A withNewException(char[] arg1,int arg2,int arg3);
    public A withNewException(byte[] arg1,int arg2,int arg3);
    public A withNewException(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewException(String arg1);
    public String getMessage();
    public A withMessage(String message);
    public Boolean hasMessage();
    public A withNewMessage(StringBuilder arg1);
    public A withNewMessage(int[] arg1,int arg2,int arg3);
    public A withNewMessage(char[] arg1);
    public A withNewMessage(StringBuffer arg1);
    public A withNewMessage(byte[] arg1,int arg2);
    public A withNewMessage(byte[] arg1);
    public A withNewMessage(char[] arg1,int arg2,int arg3);
    public A withNewMessage(byte[] arg1,int arg2,int arg3);
    public A withNewMessage(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewMessage(String arg1);
    public String getMethodname();
    public A withMethodname(String methodname);
    public Boolean hasMethodname();
    public A withNewMethodname(StringBuilder arg1);
    public A withNewMethodname(int[] arg1,int arg2,int arg3);
    public A withNewMethodname(char[] arg1);
    public A withNewMethodname(StringBuffer arg1);
    public A withNewMethodname(byte[] arg1,int arg2);
    public A withNewMethodname(byte[] arg1);
    public A withNewMethodname(char[] arg1,int arg2,int arg3);
    public A withNewMethodname(byte[] arg1,int arg2,int arg3);
    public A withNewMethodname(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewMethodname(String arg1);
}

==> chaosmesh-model-5.3.2-sources.jar: annotations/io/fabric8/chaosmesh/v1alpha1/JVMExceptionSpecFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.StringBuffer;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;

public interface JVMExceptionSpecFluent<A extends JVMExceptionSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A> {


    public Boolean getAfter();
    public A withAfter(Boolean after);
    public Boolean hasAfter();
    public A withNewAfter(String arg1);
    public A withNewAfter(boolean arg1);
    public String getClassname();
    public A withClassname(String classname);
    public Boolean hasClassname();
    public A withNewClassname(StringBuilder arg1);
    public A withNewClassname(int[] arg1,int arg2,int arg3);
    public A withNewClassname(char[] arg1);
    public A withNewClassname(StringBuffer arg1);
    public A withNewClassname(byte[] arg1,int arg2);
    public A withNewClassname(byte[] arg1);
    public A withNewClassname(char[] arg1,int arg2,int arg3);
    public A withNewClassname(byte[] arg1,int arg2,int arg3);
    public A withNewClassname(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewClassname(String arg1);
    public String getException();
    public A withException(String exception);
    public Boolean hasException();
    public A withNewException(StringBuilder arg1);
    public A withNewException(int[] arg1,int arg2,int arg3);
    public A withNewException(char[] arg1);
    public A withNewException(StringBuffer arg1);
    public A withNewException(byte[] arg1,int arg2);
    public A withNewException(byte[] arg1);
    public A withNewException(char[] arg1,int arg2,int arg3);
    public A withNewException(byte[] arg1,int arg2,int arg3);
    public A withNewException(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewException(String arg1);
    public String getMessage();
    public A withMessage(String message);
    public Boolean hasMessage();
    public A withNewMessage(StringBuilder arg1);
    public A withNewMessage(int[] arg1,int arg2,int arg3);
    public A withNewMessage(char[] arg1);
    public A withNewMessage(StringBuffer arg1);
    public A withNewMessage(byte[] arg1,int arg2);
    public A withNewMessage(byte[] arg1);
    public A withNewMessage(char[] arg1,int arg2,int arg3);
    public A withNewMessage(byte[] arg1,int arg2,int arg3);
    public A withNewMessage(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewMessage(String arg1);
    public String getMethodname();
    public A withMethodname(String methodname);
    public Boolean hasMethodname();
    public A withNewMethodname(StringBuilder arg1);
    public A withNewMethodname(int[] arg1,int arg2,int arg3);
    public A withNewMethodname(char[] arg1);
    public A withNewMethodname(StringBuffer arg1);
    public A withNewMethodname(byte[] arg1,int arg2);
    public A withNewMethodname(byte[] arg1);
    public A withNewMethodname(char[] arg1,int arg2,int arg3);
    public A withNewMethodname(byte[] arg1,int arg2,int arg3);
    public A withNewMethodname(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewMethodname(String arg1);
}
